==> libosl_0.4.3.orig.tar.gz: libosl_0.4.3.orig/doc/html/search/variables_77.js <==
var searchData=
[
  ['weight',['weight',['../classosl_1_1eval_1_1ml_1_1RookPawn.html#af218c6c018cd46501ae1657194190c69',1,'osl::eval::ml::RookPawn::weight()'],['../classosl_1_1eval_1_1ml_1_1AllMajor.html#ae325b5edcfda47198bbff5c4a830a72e',1,'osl::eval::ml::AllMajor::weight()'],['../classosl_1_1eval_1_1ml_1_1NoPawnOnStand.html#adfcd25ddd50ce0aa1657c5091032541d',1,'osl::eval::ml::NoPawnOnStand::weight()'],['../classosl_1_1eval_1_1ml_1_1AllGold.html#a32262c8da04a0a26f7916407c84329d3',1,'osl::eval::ml::AllGold::weight()'],['../classosl_1_1eval_1_1ml_1_1KnightCheck.html#a74438e3a48ad37ef86d067493182bd85',1,'osl::eval::ml::KnightCheck::weight()'],['../classosl_1_1record_1_1opening_1_1WMove.html#a8bac1e5b92f3b9aba9aa7562438ee445',1,'osl::record::opening::WMove::weight()']]],
  ['weight_5fcoef',['weight_coef',['../classosl_1_1game__playing_1_1WeightTracer.html#a77cf04459e94e0bb3c664604c21cab59',1,'osl::game_playing::WeightTracer']]],
  ['weight_5fcoef_5ffor_5fthe_5finitial_5fmove',['weight_coef_for_the_initial_move',['../classosl_1_1game__playing_1_1WeightTracer.html#a482e667bcab666d2f798d0f95dbf8066',1,'osl::game_playing::WeightTracer']]],
  ['weights',['weights',['../classosl_1_1move__probability_1_1StandardFeatureSet.html#a76e7c540bce059de67da7405a2c64e9a',1,'osl::move_probability::StandardFeatureSet::weights()'],['../classosl_1_1rating_1_1FeatureSet.html#a2af1232aff463b20f46f974ca536f33f',1,'osl::rating::FeatureSet::weights()']]],
  ['weightslog10',['weightslog10',['../classosl_1_1rating_1_1FeatureSet.html#a2767471e998d451614989dd0de17348a',1,'osl::rating::FeatureSet']]],
  ['white',['White',['../classosl_1_1record_1_1Color.html#a72f5a5c976ff4f7ae95f79d969432635',1,'osl::record::Color']]],
  ['white_5fattack_5feffect',['white_attack_effect',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a29c9f870bdc2c5607738b3bd1e17138e',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['white_5fattack_5fpiece',['white_attack_piece',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a5d4e9288e0cf45010cda601905342f52',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['white_5fattack_5fsupported_5fpiece',['white_attack_supported_piece',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a08e5fc6257f6bbd7442c72bd84540302',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['white_5fcolor',['white_color',['../classosl_1_1record_1_1KanjiPrint.html#a472999d98d511c7735cbae5e421e4b53',1,'osl::record::KanjiPrint']]],
  ['white_5fdanger',['white_danger',['../structosl_1_1eval_1_1ProgressDebugInfo.html#a64e3048ba7420dfd8def1f0cf88551b1',1,'osl::eval::ProgressDebugInfo']]],
  ['white_5fdefense',['white_defense',['../structosl_1_1eval_1_1ProgressDebugInfo.html#ad5f4e97317f56cd7c86ee22373f4c82a',1,'osl::eval::ProgressDebugInfo']]],
  ['white_5fdefense_5feffect',['white_defense_effect',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#aad30f51416e06a0ed9702b067343f8fb',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['white_5fdefense_5fpiece',['white_defense_piece',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a3d3d57e36a4d90982da8d8579c23eb09',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['white_5fking_5fvertical',['white_king_vertical',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a47bd9b24beccf7a0c21c52412351a94e',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['white_5fstand',['white_stand',['../structosl_1_1checkmate_1_1Dfpn_1_1ProofOracle.html#acb382389464ef2e88ef1b53941291825',1,'osl::checkmate::Dfpn::ProofOracle::white_stand()'],['../classosl_1_1ntesuki_1_1NtesukiRecord.html#a8971a6cbad4418aeca650a5f1a742093',1,'osl::ntesuki::NtesukiRecord::white_stand()'],['../structosl_1_1checkmate_1_1Dfpn_1_1NodeBase.html#ae18262a8bbd07fcc5d26bce74c9f8221',1,'osl::checkmate::Dfpn::NodeBase::white_stand()']]],
  ['white_5fvalues',['white_values',['../structosl_1_1progress_1_1ml_1_1NewProgressDebugInfo.html#ad8dabe0c4fe13859a94727acf424aa68',1,'osl::progress::ml::NewProgressDebugInfo']]],
  ['white_5fvertical',['white_vertical',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#afd5d5f5c4d8bf9cab60144642fd114ea',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['whitewincount',['whiteWinCount',['../classOBState.html#ade4c283f50388ce013df9259394ff868',1,'OBState']]],
  ['width',['width',['../classSearcher.html#a97a442728c24adb7a9505599466e51f6',1,'Searcher::width()'],['../ratingstat_8cc.html#a837aabdd54757cb86d0f66387511753f',1,'width():&#160;ratingstat.cc']]],
  ['width_5f',['width_',['../classosl_1_1stat_1_1Histogram.html#a5e70ed6a3069a1cd408c331ea3e8197c',1,'osl::stat::Histogram']]],
  ['window',['window',['../structosl_1_1search_1_1AlphaBeta2Tree_1_1NextQMove.html#a7d17f2dca57352552b2a81baae8f4a74',1,'osl::search::AlphaBeta2Tree::NextQMove::window()'],['../structosl_1_1search_1_1AlphaBeta2Tree_1_1NextMove.html#a991f05710a76bdba93c51c417ba9c057',1,'osl::search::AlphaBeta2Tree::NextMove::window()']]],
  ['winloss',['winloss',['../structResult.html#abc2b8eed2f8caf8421dfdc658f141151',1,'Result']]],
  ['wins',['wins',['../classosl_1_1rating_1_1BradleyTerry_1_1Thread.html#a7f7048aa02a918d2941dcb3672060526',1,'osl::rating::BradleyTerry::Thread::wins()'],['../structWinLoss.html#a4b27140848b108cf25bf6196280ca2f8',1,'WinLoss::wins()']]],
  ['working_5fthreads',['working_threads',['../structosl_1_1checkmate_1_1DfpnRecordBase.html#ab7128ae47d7031e723b1bd57642c089d',1,'osl::checkmate::DfpnRecordBase']]],
  ['written',['written',['../classosl_1_1search_1_1analyzer_1_1DotWriter.html#a880b648617e75bd381e15f75f4d82aed',1,'osl::search::analyzer::DotWriter']]],
  ['written_5fcount',['written_count',['../classosl_1_1ntesuki_1_1NtesukiRecord.html#a8d4ea79cb043a65174c0fd10a505e736',1,'osl::ntesuki::NtesukiRecord']]]
];

==> libosl_0.5.0.orig.tar.gz: libosl_0.5.0.orig/doc/html/search/variables_77.js <==
var searchData=
[
  ['weight',['weight',['../classosl_1_1eval_1_1ml_1_1RookPawn.html#af218c6c018cd46501ae1657194190c69',1,'osl::eval::ml::RookPawn::weight()'],['../classosl_1_1eval_1_1ml_1_1AllMajor.html#ae325b5edcfda47198bbff5c4a830a72e',1,'osl::eval::ml::AllMajor::weight()'],['../classosl_1_1eval_1_1ml_1_1NoPawnOnStand.html#adfcd25ddd50ce0aa1657c5091032541d',1,'osl::eval::ml::NoPawnOnStand::weight()'],['../classosl_1_1eval_1_1ml_1_1AllGold.html#a32262c8da04a0a26f7916407c84329d3',1,'osl::eval::ml::AllGold::weight()'],['../classosl_1_1eval_1_1ml_1_1KnightCheck.html#a74438e3a48ad37ef86d067493182bd85',1,'osl::eval::ml::KnightCheck::weight()'],['../classosl_1_1record_1_1opening_1_1WMove.html#a8bac1e5b92f3b9aba9aa7562438ee445',1,'osl::record::opening::WMove::weight()'],['../learn-piece_8cc.html#acaa411f8865ab6fd50ea9c8f2932f3b6',1,'weight():&#160;learn-piece.cc']]],
  ['weight_5fcoef',['weight_coef',['../classosl_1_1game__playing_1_1WeightTracer.html#a77cf04459e94e0bb3c664604c21cab59',1,'osl::game_playing::WeightTracer']]],
  ['weight_5fcoef_5ffor_5fthe_5finitial_5fmove',['weight_coef_for_the_initial_move',['../classosl_1_1game__playing_1_1WeightTracer.html#a482e667bcab666d2f798d0f95dbf8066',1,'osl::game_playing::WeightTracer']]],
  ['weights',['weights',['../classosl_1_1move__probability_1_1StandardFeatureSet.html#a76e7c540bce059de67da7405a2c64e9a',1,'osl::move_probability::StandardFeatureSet::weights()'],['../classosl_1_1rating_1_1FeatureSet.html#a2af1232aff463b20f46f974ca536f33f',1,'osl::rating::FeatureSet::weights()']]],
  ['weightslog10',['weightslog10',['../classosl_1_1rating_1_1FeatureSet.html#a2767471e998d451614989dd0de17348a',1,'osl::rating::FeatureSet']]],
  ['white',['White',['../classosl_1_1record_1_1Color.html#a72f5a5c976ff4f7ae95f79d969432635',1,'osl::record::Color']]],
  ['white_5fattack_5feffect',['white_attack_effect',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a29c9f870bdc2c5607738b3bd1e17138e',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['white_5fattack_5fpiece',['white_attack_piece',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a5d4e9288e0cf45010cda601905342f52',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['white_5fattack_5fsupported_5fpiece',['white_attack_supported_piece',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a08e5fc6257f6bbd7442c72bd84540302',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['white_5fcolor',['white_color',['../classosl_1_1record_1_1KanjiPrint.html#a472999d98d511c7735cbae5e421e4b53',1,'osl::record::KanjiPrint']]],
  ['white_5fdanger',['white_danger',['../structosl_1_1eval_1_1ProgressDebugInfo.html#a64e3048ba7420dfd8def1f0cf88551b1',1,'osl::eval::ProgressDebugInfo']]],
  ['white_5fdefense',['white_defense',['../structosl_1_1eval_1_1ProgressDebugInfo.html#ad5f4e97317f56cd7c86ee22373f4c82a',1,'osl::eval::ProgressDebugInfo']]],
  ['white_5fdefense_5feffect',['white_defense_effect',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#aad30f51416e06a0ed9702b067343f8fb',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['white_5fdefense_5fpiece',['white_defense_piece',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a3d3d57e36a4d90982da8d8579c23eb09',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['white_5fking_5fvertical',['white_king_vertical',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a47bd9b24beccf7a0c21c52412351a94e',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['white_5fstand',['white_stand',['../structosl_1_1checkmate_1_1Dfpn_1_1ProofOracle.html#acb382389464ef2e88ef1b53941291825',1,'osl::checkmate::Dfpn::ProofOracle::white_stand()'],['../classosl_1_1ntesuki_1_1NtesukiRecord.html#a8971a6cbad4418aeca650a5f1a742093',1,'osl::ntesuki::NtesukiRecord::white_stand()'],['../structosl_1_1checkmate_1_1Dfpn_1_1NodeBase.html#ae18262a8bbd07fcc5d26bce74c9f8221',1,'osl::checkmate::Dfpn::NodeBase::white_stand()']]],
  ['white_5fvalues',['white_values',['../structosl_1_1progress_1_1ml_1_1NewProgressDebugInfo.html#ad8dabe0c4fe13859a94727acf424aa68',1,'osl::progress::ml::NewProgressDebugInfo']]],
  ['white_5fvertical',['white_vertical',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#afd5d5f5c4d8bf9cab60144642fd114ea',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['whitewincount',['whiteWinCount',['../classOBState.html#ade4c283f50388ce013df9259394ff868',1,'OBState']]],
  ['width',['width',['../classSearcher.html#a97a442728c24adb7a9505599466e51f6',1,'Searcher::width()'],['../ratingstat_8cc.html#a837aabdd54757cb86d0f66387511753f',1,'width():&#160;ratingstat.cc']]],
  ['width_5f',['width_',['../classosl_1_1stat_1_1Histogram.html#a5e70ed6a3069a1cd408c331ea3e8197c',1,'osl::stat::Histogram']]],
  ['window',['window',['../structosl_1_1search_1_1AlphaBeta2Tree_1_1NextQMove.html#a7d17f2dca57352552b2a81baae8f4a74',1,'osl::search::AlphaBeta2Tree::NextQMove::window()'],['../structosl_1_1search_1_1AlphaBeta2Tree_1_1NextMove.html#a991f05710a76bdba93c51c417ba9c057',1,'osl::search::AlphaBeta2Tree::NextMove::window()']]],
  ['winloss',['winloss',['../structResult.html#abc2b8eed2f8caf8421dfdc658f141151',1,'Result']]],
  ['wins',['wins',['../classosl_1_1rating_1_1BradleyTerry_1_1Thread.html#a7f7048aa02a918d2941dcb3672060526',1,'osl::rating::BradleyTerry::Thread::wins()'],['../structWinLoss.html#a4b27140848b108cf25bf6196280ca2f8',1,'WinLoss::wins()']]],
  ['working_5fthreads',['working_threads',['../structosl_1_1checkmate_1_1DfpnRecordBase.html#ab7128ae47d7031e723b1bd57642c089d',1,'osl::checkmate::DfpnRecordBase']]],
  ['written',['written',['../classosl_1_1search_1_1analyzer_1_1DotWriter.html#a880b648617e75bd381e15f75f4d82aed',1,'osl::search::analyzer::DotWriter']]],
  ['written_5fcount',['written_count',['../classosl_1_1ntesuki_1_1NtesukiRecord.html#a8d4ea79cb043a65174c0fd10a505e736',1,'osl::ntesuki::NtesukiRecord']]]
];
